<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Clipboard</name>
    <message>
        <source>Copy color %1 to clipboard</source>
        <translation>拷贝颜色%1到剪切板</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>深度取色器是一款帮助您快速在屏幕上取色的工具。并且能根据您拾取的颜色得到RGB、HEX代码。打开软件后，鼠标经过的地方即为深度取色器取色的区域。</translation>
    </message>
    <message>
        <source>Deepin Picker</source>
        <translation>深度取色器</translation>
    </message>
</context>
</TS>
